==> knative-model-4.6.3-sources.jar: annotations/io/fabric8/knative/eventing/v1alpha1/ClusterChannelProvisionerStatusFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import io.fabric8.knative.v1.Condition;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.knative.v1.ConditionBuilder;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ClusterChannelProvisionerStatusFluent<A extends ClusterChannelProvisionerStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> addNewCondition();
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> editCondition(int index);
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> editFirstCondition();
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> editLastCondition();
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();

    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<ClusterChannelProvisionerStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}

==> knative-model-4.7.0-sources.jar: annotations/io/fabric8/knative/eventing/v1alpha1/ClusterChannelProvisionerStatusFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.knative.v1.ConditionBuilder;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ClusterChannelProvisionerStatusFluent<A extends ClusterChannelProvisionerStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> addNewCondition();
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> editCondition(int index);
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> editFirstCondition();
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> editLastCondition();
    public ClusterChannelProvisionerStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();

    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<ClusterChannelProvisionerStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}
